@@ -2,10 +2,12 @@
 # pylint: disable=C0103
 from .foldingathomecontrol import FoldingAtHomeController  # noqa
 from .exceptions import (  # noqa
+    FoldingAtHomeControlException,
     FoldingAtHomeControlAuthenticationFailed,
     FoldingAtHomeControlAuthenticationRequired,
     FoldingAtHomeControlConnectionFailed,
+    FoldingAtHomeControlNotConnected,
 )
 from .const import PyOnMessageTypes  # noqa
 
-__version__ = "0.2.1"
+__version__ = "0.3.1"
